reporting Package
=================

:mod:`reporting` Package
------------------------

.. automodule:: stoqlib.reporting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`boleto` Module
--------------------

.. automodule:: stoqlib.reporting.boleto
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`calls_report` Module
--------------------------

.. automodule:: stoqlib.reporting.calls_report
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventory` Module
-----------------------

.. automodule:: stoqlib.reporting.inventory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loanreceipt` Module
-------------------------

.. automodule:: stoqlib.reporting.loanreceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payment` Module
---------------------

.. automodule:: stoqlib.reporting.payment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payments_receipt` Module
------------------------------

.. automodule:: stoqlib.reporting.payments_receipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`product` Module
---------------------

.. automodule:: stoqlib.reporting.product
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`production` Module
------------------------

.. automodule:: stoqlib.reporting.production
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchase` Module
----------------------

.. automodule:: stoqlib.reporting.purchase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchase_receival` Module
-------------------------------

.. automodule:: stoqlib.reporting.purchase_receival
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sale` Module
------------------

.. automodule:: stoqlib.reporting.sale
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`service` Module
---------------------

.. automodule:: stoqlib.reporting.service
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreasereceipt` Module
----------------------------------

.. automodule:: stoqlib.reporting.stockdecreasereceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`template` Module
----------------------

.. automodule:: stoqlib.reporting.template
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`till` Module
------------------

.. automodule:: stoqlib.reporting.till
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transfer_receipt` Module
------------------------------

.. automodule:: stoqlib.reporting.transfer_receipt
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.reporting.base

